@@ -1,3 +1,4 @@
-from .settings import *  # noqa
+from testproject.settings import *  # noqa
+
 
 FORM_RENDERER = "django.forms.renderers.Jinja2"
